@@ -20,6 +20,7 @@ else:
 
 
 try:
+    from doorstop.common import DoorstopError
     from doorstop.core import Item, Document, Tree, build
-except ImportError:
+except ImportError:  # pragma: no cover, manual test
     pass
