@@ -10,12 +10,14 @@ import argparse
 import logging
 
 from doorstop import CLI, VERSION
-from doorstop.cli import settings
+from doorstop.gui.main import run as gui
 from doorstop.core.tree import build
 from doorstop.core import report
 from doorstop.common import DoorstopError
+from doorstop import settings
 
 
+# TODO: use the classes from doorstop.common
 class _HelpFormatter(argparse.HelpFormatter):
     """Command-line help text formatter with wider help text."""
     def __init__(self, *args, **kwargs):
@@ -136,7 +138,10 @@ def main(args=None):  # pylint: disable=R0915
     _configure_logging(args.verbose)
 
     # Run the program
-    if args.command:
+    if args.gui:
+        logging.debug("launching GUI...")
+        function = gui
+    elif args.command:
         logging.debug("launching command '{}'...".format(args.command))
         function = globals()['_run_' + args.command]
     else:
@@ -148,7 +153,7 @@ def main(args=None):  # pylint: disable=R0915
         logging.debug("command cancelled")
         success = False
     if success:
-        logging.debug("command succedded")
+        logging.debug("command succeeded")
     else:
         logging.debug("command failed")
         sys.exit(1)
@@ -191,7 +196,8 @@ def _run(args, cwd, err):  # pylint: disable=W0613
         logging.error(error)
         return False
     else:
-        print("validated: {}".format(tree))
+        if tree:
+            print("validated: {}".format(tree))
         return True
 
 
