@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 Representation of a collection of Doorstop items.
 """
@@ -69,6 +67,11 @@ class Document(object):
     def __ne__(self, other):
         return not self == other
 
+    @property
+    def config(self):
+        """Get the path to the document's configuration."""
+        return os.path.join(self.path, Document.CONFIG)
+
     @staticmethod
     def new(path, root, prefix, parent=None, digits=None):
         """Create a new Document.
@@ -117,7 +120,7 @@ class Document(object):
 
     def _read(self):  # pragma: no cover, integration test
         """Read text from the file."""
-        path = os.path.join(self.path, Document.CONFIG)
+        path = self.config
         if not os.path.exists(path):
             logging.debug("document does not exist yet: {}".format(path))
             return ""
@@ -137,7 +140,7 @@ class Document(object):
 
     def _write(self, text):  # pragma: no cover, integration test
         """Write text to the file."""
-        path = os.path.join(self.path, Document.CONFIG)
+        path = self.config
         with open(path, 'wb') as outfile:
             outfile.write(bytes(text, 'UTF-8'))
 
@@ -168,9 +171,12 @@ class Document(object):
         except ValueError:
             return 0
 
-    def check(self):
+    def check(self, tree=None, ignored=None):
         """Confirm the document is valid.
 
+        @param tree: tree to validate the document
+        @param ignored: function to determine if a path should be skipped
+
         @return: indication that document is valid
         """
         logging.info("checking document {}...".format(self))
@@ -180,6 +186,6 @@ class Document(object):
             logging.warning("no items: {}".format(self))
         # Check each item
         for item in items:
-            item.check()
+            item.check(document=self, tree=tree, ignored=ignored)
         # Document is valid
         return True
