@@ -36,7 +36,8 @@ def _auto_load(func):
     def wrapped(self, *args, **kwargs):
         """Wrapped method to call self.load() before execution."""
         self.load()
-        return func(self, *args, **kwargs)
+        if self.auto:
+            return func(self, *args, **kwargs)
     return wrapped
 
 
@@ -46,7 +47,8 @@ def _auto_save(func):
     def wrapped(self, *args, **kwargs):
         """Wrapped method to call self.save() after execution."""
         result = func(self, *args, **kwargs)
-        self.save()
+        if self.auto:
+            self.save()
         return result
 
     return wrapped
@@ -61,15 +63,15 @@ class Item(object):
     DEFAULT_TEXT = ""
     DEFAULT_REF = ""
     DEFAULT_LINKS = set()
+    DEFAULT_NORMATIVE = True
 
-    def __init__(self, path, root=os.getcwd(),
-                 _level=None,
-                 # TODO: are these arguments needed here?
-                 _text=None, _ref=None, _links=None):
+    auto = True  # set to False to delay automatic load/save until load/save
+
+    def __init__(self, path, root=os.getcwd()):
         """Load an item from an existing file.
 
         Internally, this constructor is also used to initialize new
-        items by providing default properites.
+        items by providing default properties.
 
         @param path: path to Item file
         @param root: path to root of project
@@ -92,10 +94,12 @@ class Item(object):
         self.path = path
         self.root = root
         self._exists = True
-        self._level = _level or Item.DEFAULT_LEVEL
-        self._text = _text or Item.DEFAULT_TEXT
-        self._ref = _ref or Item.DEFAULT_REF
-        self._links = _links or Item.DEFAULT_LINKS
+        self._level = Item.DEFAULT_LEVEL
+        self._text = Item.DEFAULT_TEXT
+        self._ref = Item.DEFAULT_REF
+        self._links = Item.DEFAULT_LINKS
+        self._normative = Item.DEFAULT_NORMATIVE
+        self._data = {}
 
     def __repr__(self):
         return "Item({})".format(repr(self.path))
@@ -135,8 +139,8 @@ class Item(object):
         # Create the item file
         Item._new(path2)
         # Return the new item
-        item = Item(path2, root=root, _level=level)
-        item.save()
+        item = Item(path2, root=root)
+        item.level = level or Item.DEFAULT_LEVEL  # also saves the item
         return item
 
     @staticmethod
@@ -157,17 +161,19 @@ class Item(object):
         text = self._read()
         # Parse the YAML data
         try:
-            data = yaml.load(text)
+            self._data = yaml.load(text) or {}
         except yaml.scanner.ScannerError as error:  # pylint: disable=E1101
             msg = "invalid contents: {}:\n{}".format(self, error)
             raise DoorstopError(msg)
         # Store parsed data
-        if data:
-            self._level = self._convert_level(data.get('level', self._level))
-            self._text = data.get('text', self._text)
-            self._ref = data.get('ref', self._ref)
-            self._links = set(data.get('links', self._links))
+        self._level = self._convert_level(self._data.get('level', self._level))
+        self._text = self._data.get('text', self._text).strip()
+        self._ref = self._data.get('ref', self._ref)
+        self._links = set(self._data.get('links', self._links))
+        self._normative = bool(self._data.get('normative', self._normative))
+        # Set meta attributes
         setattr(self, '_loaded', True)
+        self.auto = True
 
     def _read(self):  # pragma: no cover, integration test
         """Read text from the file."""
@@ -188,29 +194,37 @@ class Item(object):
         text = _literal(self._sbd(self._text))
         ref = self._ref.strip()
         links = sorted(self._links)
+        normative = self._normative
         # Build the data structure
-        data = {'level': level,
-                'text': text,
-                'links': links,
-                'ref': ref}
+        self._data['level'] = level
+        self._data['text'] = text
+        self._data['links'] = links
+        self._data['ref'] = ref
+        self._data['normative'] = normative
         # Dump the data to YAML
-        dump = yaml.dump(data, default_flow_style=False)
+        dump = yaml.dump(self._data, default_flow_style=False)
         # Save the YAML to file
         self._write(dump)
+        # Set meta attributes
         setattr(self, '_loaded', False)
+        self.auto = True
 
     @staticmethod
     def _sbd(text):
-        """Replace sentence boundaries with newlines.
+        """Replace sentence boundaries with newlines and append a newline.
 
         >>> Item._sbd("Hello, world!")
-        'Hello, world!'
+        'Hello, world!\\n'
 
         >>> Item._sbd("Hello, world! How are you? I'm fine. Good.")
-        "Hello, world!\\nHow are you?\\nI'm fine.\\nGood."
+        "Hello, world!\\nHow are you?\\nI'm fine.\\nGood.\\n"
 
         """
-        return SBD.sub('\n', text.strip())
+        stripped = text.strip()
+        if stripped:
+            return SBD.sub('\n', stripped) + '\n'
+        else:
+            return ''
 
     def _write(self, text):  # pragma: no cover, integration test
         """Write text to the file."""
@@ -241,8 +255,11 @@ class Item(object):
         >>> Item.split_id('ABC00123')
         ('ABC', 123)
 
+        >>> Item.split_id('ABC.HLR_01-00123')
+        ('ABC.HLR_01-', 123)
+
         """
-        match = re.match(r"([a-zA-Z]+)(\d+)", text)
+        match = re.match(r"([\w.-]*\D)(\d+)", text)
         if not match:
             raise DoorstopError("invalid ID: {}".format(text))
         return match.group(1), int(match.group(2))
@@ -332,7 +349,9 @@ class Item(object):
         @param root: override the path to the working copy (for testing)
         @param ignored: function to determine if a path should be skipped
 
-        @return: path to file, line number (or None, None when no ref)
+        @return: relative path to file, line number (when found in file)
+                 relative path to file, None (when found as filename)
+                 None, None (when no ref)
 
         @raise DoorstopError: when no ref is found
         """
@@ -347,6 +366,7 @@ class Item(object):
         for root, _, filenames in os.walk(root or self.root):
             for filename in filenames:  # pragma: no cover, integration test
                 path = os.path.join(root, filename)
+                relpath = os.path.relpath(path, self.root)
                 # Skip the item's file while searching
                 if path == self.path:
                     continue
@@ -357,12 +377,14 @@ class Item(object):
                 if ignored(path):
                     continue
                 # Search for the reference in the file
+                if filename == self.ref:
+                    return relpath, None
                 try:
                     with open(path, 'r') as external:
                         for index, line in enumerate(external):
                             if regex.search(line):
-                                logging.info("found ref: {}".format(path))
-                                return path, index + 1
+                                logging.info("found ref: {}".format(relpath))
+                                return relpath, index + 1
                 except UnicodeDecodeError:
                     pass
         msg = "external reference not found: {}".format(self.ref)
@@ -380,6 +402,18 @@ class Item(object):
         """Set the items this item links to."""
         self._links = set(links)
 
+    @property
+    @_auto_load
+    def normative(self):
+        """Get the item's normative status."""
+        return self._normative
+
+    @normative.setter
+    @_auto_save
+    def normative(self, status):
+        """Set the item's normative status."""
+        self._normative = bool(status)
+
     @_auto_load
     @_auto_save
     def add_link(self, item):
@@ -395,6 +429,17 @@ class Item(object):
         except KeyError:
             logging.warning("link to {0} does not exist".format(item))
 
+    @_auto_load
+    def get(self, name):
+        """Get an extended attribute."""
+        return self._data[name]
+
+    @_auto_load
+    @_auto_save
+    def set(self, name, value):
+        """SEt an extended attribute."""
+        self._data[name] = value
+
     def check(self, document=None, tree=None, ignored=None):
         """Confirm the item is valid.
 
@@ -414,28 +459,55 @@ class Item(object):
         self.find_ref(ignored=ignored)
         # Check links against the document
         if document:
-            if document.parent and self.level[-1] != 0 and not self.links:
-                logging.warning("no links: {}".format(self))
-
-            for identifier in self.links:
-                prefix = self.split_id(identifier)[0]
-                if prefix.lower() != document.parent.lower():
-                    msg = "link to non-parent '{}' in {}".format(identifier,
-                                                                 self)
-                    logging.warning(msg)
+            self._check_document(document)
         # Check links against the tree
         if tree:
-            for identifier in self.links:
-                item = tree.find_item(identifier)
-                logging.debug("found linked item: {}".format(item))
-
+            self._check_tree(tree)
         # Reformat the file
         self.save()
         # Item is valid
         return True
 
+    def _check_document(self, document):
+        """Check the item against its document."""
+        # Verify an item has up links
+        if document.parent and self.normative and not self.links:
+            logging.warning("no links: {}".format(self))
+        # Verify an item's links are to the correct parent
+        for identifier in self.links:
+            prefix = self.split_id(identifier)[0]
+            if prefix.lower() != document.parent.lower():
+                msg = "link to non-parent '{}' in {}".format(identifier, self)
+                logging.warning(msg)
+
+    def _check_tree(self, tree):
+        """Check the item against the full tree."""
+        # Verify an item's links are valid
+        for identifier in self.links:
+            item = tree.find_item(identifier)
+            logging.debug("found linked item: {}".format(item))
+        # Verify an item has down links
+        for document in tree:
+            if document.parent == self.prefix:
+                links = []
+                for item in document:
+                    if self.id in item.links:
+                        links.append(item.id)
+                if links:
+                    if self.normative:
+                        msg = "down links: {}".format(', '.join(links))
+                        logging.debug(msg)
+                    else:
+                        for link in links:
+                            msg = "{} links to non-normative {}".format(link,
+                                                                        self)
+                            logging.warning(msg)
+                elif self.normative:
+                    msg = "{} has no links from {}".format(self, document)
+                    logging.warning(msg)
+
     def delete(self):
         """Delete the item from the file system."""
         logging.info("deleting {}...".format(self.path))
         os.remove(self.path)
-        self._exists = False  # prevent furthur access
+        self._exists = False  # prevent future access
