@@ -13,7 +13,7 @@ import logging
 from doorstop.common import DoorstopError
 from doorstop.core.item import Item
 
-from doorstop.core.test import ENV, REASON, FILES, EMPTY
+from doorstop.core.test import ENV, REASON, FILES, EMPTY, EXTERNAL
 
 
 class MockItem(Item):
@@ -67,10 +67,11 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
     def test_save_empty(self):
         """Verify saving calls write."""
         self.item.save()
-        text = ("level: 1\n"
-                "links: []\n"
-                "ref: ''\n"
-                "text: ''\n")
+        text = ("level: 1" + '\n'
+                "links: []" + '\n'
+                "normative: true" + '\n'
+                "ref: ''" + '\n'
+                "text: ''" + '\n')
         self.item._write.assert_called_once_with(text)
 
     def test_str(self):
@@ -84,9 +85,11 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
 
     def test_lt(self):
         """Verify items can be compared."""
-        item0 = MockItem('path/to/RQ002.yml', _level=(1, 1))
+        item0 = MockItem('path/to/RQ002.yml')
+        item0.level = (1, 1)
         item1 = self.item
-        item2 = MockItem('path/to/RQ003.yml', _level=(1, 1, 2))
+        item2 = MockItem('path/to/RQ003.yml')
+        item2.level = (1, 1, 2)
         self.assertLess(item0, item1)
         self.assertLess(item1, item2)
         self.assertGreater(item2, item0)
@@ -143,20 +146,20 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
 
     def test_text(self):
         """Verify an item's text can be set and read."""
-        self.item.text = "test "
-        self.assertIn("text: |-\n  test\n", self.item._write.call_args[0][0])
-        self.assertEqual("test", self.item.text)
+        self.item.text = "abc "
+        self.assertIn("text: |\n  abc\n", self.item._write.call_args[0][0])
+        self.assertEqual("abc", self.item.text)
 
     def test_text_sentences(self):
         """Verify newlines separate sentences in an item's text."""
         self.item.text = ("A sentence. Another sentence! Hello? Hi.\n"
-                          "A new line. And another sentece.")
+                          "A new line. And another sentence.")
         expected = ("A sentence.\n"
                     "Another sentence!\n"
                     "Hello?\n"
                     "Hi.\n"
                     "A new line.\n"
-                    "And another sentece.")
+                    "And another sentence.")
         self.assertEqual(expected, self.item.text)
 
     def test_ref(self):
@@ -165,6 +168,20 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
         self.assertIn("ref: abc123\n", self.item._write.call_args[0][0])
         self.assertEqual("abc123", self.item.ref)
 
+    def test_find_ref(self):
+        """Verify an item's reference can be found."""
+        self.item.ref = "REF" + "123"  # to avoid matching in this file
+        relpath, line = self.item.find_ref(EXTERNAL)
+        self.assertEqual('text.txt', os.path.basename(relpath))
+        self.assertEqual(3, line)
+
+    def test_find_ref_filename(self):
+        """Verify an item's reference can also be a filename."""
+        self.item.ref = "text.txt"
+        relpath, line = self.item.find_ref(FILES)
+        self.assertEqual('text.txt', os.path.basename(relpath))
+        self.assertEqual(None, line)
+
     def test_find_ref_error(self):
         """Verify an error occurs when no external reference found."""
         self.item.ref = "not found".replace(' ', '')  # avoids self match
@@ -199,6 +216,17 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
         self.item.remove_link('abc')
         self.assertEqual(['123'], self.item.links)
 
+    def test_normative(self):
+        """Verify an item's normative status can be set and read."""
+        self.item.normative = 0  # converted to False
+        self.assertIn("normative: false\n", self.item._write.call_args[0][0])
+        self.assertFalse(self.item.normative)
+
+    def test_extended(self):
+        """Verify an extended attribute can be used."""
+        self.item.set('ext1', 'foobar')
+        self.assertEqual('foobar', self.item.get('ext1'))
+
     def test_invalid_file_name(self):
         """Verify an invalid file name cannot be a requirement."""
         self.assertRaises(DoorstopError, MockItem, "path/to/REQ.yaml")
@@ -212,12 +240,23 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
     @patch('doorstop.core.item.Item', MockItem)
     def test_new(self):
         """Verify items can be created."""
+        MockItem._new.reset_mock()
         item = MockItem.new(EMPTY, FILES, 'TEST', 5, 42, (1, 2, 3))
         path = os.path.join(EMPTY, 'TEST00042.yml')
         self.assertEqual(path, item.path)
         self.assertEqual((1, 2, 3), item.level)
         MockItem._new.assert_called_once_with(path)
 
+    @patch('doorstop.core.item.Item', MockItem)
+    def test_new_special(self):
+        """Verify items can be created with a specially named prefix."""
+        MockItem._new.reset_mock()
+        item = MockItem.new(EMPTY, FILES, 'VSM.HLR_01-002-', 3, 42, (1,))
+        path = os.path.join(EMPTY, 'VSM.HLR_01-002-042.yml')
+        self.assertEqual(path, item.path)
+        self.assertEqual((1,), item.level)
+        MockItem._new.assert_called_once_with(path)
+
     def test_new_existing(self):
         """Verify an exception is raised if the item already exists."""
         self.assertRaises(DoorstopError,
@@ -240,6 +279,66 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
         """Verify an item can be checked against a tree."""
         self.item.add_link('fake1')
         tree = Mock(find_item=Mock())
+
+        def mock_iter(self):  # pylint: disable=W0613
+            """Mock Tree.__iter__ to yield a mock Document."""
+            mock_document = Mock()
+            mock_document.parent = 'RQ'
+
+            def mock_iter2(self):  # pylint: disable=W0613
+                """Mock Document.__iter__ to yield a mock Item."""
+                mock_item = Mock()
+                mock_item.id = 'TST001'
+                mock_item.links = ['RQ001']
+                yield mock_item
+
+            mock_document.__iter__ = mock_iter2
+            yield mock_document
+        tree.__iter__ = mock_iter
+        self.item.check(tree=tree)
+
+    def test_check_tree_non_normative(self):
+        """Verify a non-normative item can be checked against a tree."""
+        self.item.normative = False
+        self.item.add_link('fake1')
+        tree = Mock(find_item=Mock())
+
+        def mock_iter(self):  # pylint: disable=W0613
+            """Mock Tree.__iter__ to yield a mock Document."""
+            mock_document = Mock()
+            mock_document.parent = 'RQ'
+
+            def mock_iter2(self):  # pylint: disable=W0613
+                """Mock Document.__iter__ to yield a mock Item."""
+                mock_item = Mock()
+                mock_item.id = 'TST001'
+                mock_item.links = ['RQ001']
+                yield mock_item
+
+            mock_document.__iter__ = mock_iter2
+            yield mock_document
+        tree.__iter__ = mock_iter
+        self.item.check(tree=tree)
+
+    def test_check_tree_no_down_links(self):
+        """Verify an item can be checked against a tree without down links."""
+        self.item.add_link('fake1')
+        tree = Mock(find_item=Mock())
+
+        def mock_iter(self):  # pylint: disable=W0613
+            """Mock Tree.__iter__ to yield a mock Document."""
+            mock_document = Mock()
+            mock_document.parent = 'RQ'
+
+            def mock_iter2(self):  # pylint: disable=W0613
+                """Mock Document.__iter__ to yield a mock Item."""
+                mock_item = Mock()
+                mock_item.links = []
+                yield mock_item
+
+            mock_document.__iter__ = mock_iter2
+            yield mock_document
+        tree.__iter__ = mock_iter
         self.item.check(tree=tree)
 
     def test_check_tree_error(self):
