@@ -17,7 +17,7 @@ from doorstop.core import vcs
 
 class Tree(object):
     """
-    A bidirectional tree structure to store the heirarchy or documents.
+    A bidirectional tree structure to store the hierarchy or documents.
 
     Although requirements link "upwards", bidirectionality simplifies
     document processing and validation.
@@ -56,8 +56,7 @@ class Tree(object):
     def __iter__(self):
         if self.document:
             yield self.document
-        for document in chain(*(iter(c) for c in self.children)):
-            yield document
+        yield from chain(*(iter(c) for c in self.children))
 
     @staticmethod
     def from_list(docs, root=None):
@@ -266,7 +265,7 @@ class Tree(object):
         return item
 
     def find_document(self, prefix):
-        """Return an the document from its prefix.
+        """Return a document from its prefix.
 
         @param prefix: document's prefix
 
@@ -281,7 +280,7 @@ class Tree(object):
         raise DoorstopError("no matching prefix: {}".format(prefix))
 
     def find_item(self, identifier, kind=''):
-        """Return an the item from its ID.
+        """Return an item from its ID.
 
         @param identifier: item ID
         @param kind: type of item for logging messages
@@ -326,7 +325,7 @@ def _open(path, tool=None):  # pragma: no cover, integration test
 
 
 def build(cwd=None, root=None):
-    """Build a document heirachy from the current root directory.
+    """Build a document hierarchy from the current root directory.
 
     @param cwd: current working directory
     @param root: path to root of the working copy
